@@ -26,22 +26,21 @@
 #define LOCKFILE_H
 
 #include <QString>
-#include <QFile>
-
 
 class LockFile
 {
 public:
-    LockFile(QString fileName);
-
+    LockFile(const QString &file_name)
+        : file_name {file_name}
+    {
+    }
+    ~LockFile() { unlock(); };
     bool isLocked();
     bool lock();
     bool unlock();
 
 private:
     QString file_name;
-    int fd;
-
 };
 
 #endif // LOCKFILE_H
